@@ -1,4 +1,12 @@
 #' Unpack a hilo column
+#'
+#' @description 
+#' `r lifecycle::badge('superseded')`
+#' 
+#' This function is superceded. It is recommended that you use the functionality
+#' from the [distributional](https://pkg.mitchelloharawild.com/distributional/)
+#' package to extract elements from a `<hilo>` object. For example, you can access
+#' the lower bound with `<hilo>$lower`.
 #' 
 #' Allows a hilo column to be unpacked into its component columns: "lower", 
 #' "upper", and "level".
@@ -8,6 +16,7 @@
 #' 
 #' @seealso [`tidyr::unpack()`]
 #' 
+#' @keywords internal
 #' @export
 unpack_hilo <- function(data, cols, names_sep = "_", names_repair = "check_unique"){
   orig <- data
@@ -19,6 +28,6 @@ unpack_hilo <- function(data, cols, names_sep = "_", names_repair = "check_uniqu
     ))
   }
   data[cols] <- map(data[cols], function(x) vctrs::vec_proxy(x)[c("lower", "upper")])
-  data <- tidyr::unpack(data, cols, names_sep = names_sep, names_repair = names_repair)
+  data <- tidyr::unpack(data, names(cols), names_sep = names_sep, names_repair = names_repair)
   vctrs::vec_restore(data, orig)
 }
