@@ -4,7 +4,7 @@ test_that("Extracting intervals from a distribution", {
   skip_if_not_installed("fable")
   
   fc_sum <- fbl %>% 
-    mutate("80%" := hilo(!!(fbl%@%"dist"), 80))
+    mutate(`80%` = hilo(value, 80))
   
   expect_s3_class(fc_sum$`80%`, "hilo")
 })
